Skip to contents

Extracts the value column for a given measure and names each element with a combination of version/year and reporting level.

Usage

create_attr(measure, filtered_aux)

Arguments

measure

Character scalar. One of "cpi", "ppp", "pop", "gdp", "pce".

filtered_aux

A data.table of already-filtered auxiliary data, as returned by filter_aux_data().

Value

A named numeric vector of auxiliary values.