Create a named attribute vector from filtered auxiliary data
create_attr.RdExtracts the value column for a given measure and names each element with a combination of version/year and reporting level.
Arguments
- measure
Character scalar. One of
"cpi","ppp","pop","gdp","pce".- filtered_aux
A
data.tableof already-filtered auxiliary data, as returned byfilter_aux_data().
See also
Other pd_process_data pipeline:
add_attr(),
aux_hash_candidates(),
build_pip_inventory(),
data_to_dt(),
filter_aux_data(),
filter_aux_inv(),
fix_year_var(),
get_aux_hashes(),
inv_dlw_load(),
inv_to_process(),
log_report(),
pd_aux_attr(),
pd_deflation(),
save_pip_data(),
survey_id_to_attr(),
valid_dlw_load()