Retrieve a List of GMD datasets from the Server and save it in the local dlw inventory folder.
dlw_gmd_list.RdThis function fetches a list of GMD datasets from the server, filters them based on Module and file extension.
Note
This function expects a working release to be configured via
pipfun::setup_working_release(). When called from
pipdata_get_gmd(), the release is already set. When called
standalone, ensure setup_working_release() has been invoked first.
Examples
if (FALSE) { # \dontrun{
gmd_list <- dlw_gmd_list()
head(gmd_list)
} # }