Get current available GMD datasets without completed validation
dlw_gmd_unvalidated.RdReconciles the default completed validation inventory to current available
acquisition survey_id/Checksum keys and returns keys absent from completed
state. Completed state means data_available = "Yes" with status "valid"
or "invalid"; recognized legacy blank/"No" retry rows are not completed.
Consequently execution failures are returned again because they have no
completed inventory row. All seven validation module mappings may be present.
Value
Invisibly, a data.table of current available acquisition rows that
lack a completed validation row.
Examples
if (FALSE) { # \dontrun{
pipfun::setup_working_release("20260206", "TEST")
df <- dlw_gmd_unvalidated()
head(df)
} # }