Skip to contents

For each auxiliary dataset that has changed, normalises the year variable and merges the changes against the DLW inventory to identify surveys affected by those changes.

Usage

filter_aux_inv(inv, changes_aux)

Arguments

inv

A data.table of the DLW inventory.

changes_aux

A list of data.table objects representing changed rows in an auxiliary dataset, as returned by valid_aux_load().

Value

A data.table of affected surveys (latest version only), or NULL if no changes apply.