Filter DLW inventory by auxiliary-data changes
filter_aux_inv.RdFor each auxiliary dataset that has changed, normalises the year variable and merges the changes against the DLW inventory to identify surveys affected by those changes.
Arguments
- inv
A
data.tableof the DLW inventory.- changes_aux
A list of
data.tableobjects representing changed rows in an auxiliary dataset, as returned byvalid_aux_load().
See also
Other pd_process_data pipeline:
add_attr(),
aux_hash_candidates(),
build_pip_inventory(),
create_attr(),
data_to_dt(),
filter_aux_data(),
fix_year_var(),
get_aux_hashes(),
inv_dlw_load(),
inv_to_process(),
log_report(),
pd_aux_attr(),
pd_deflation(),
save_pip_data(),
survey_id_to_attr(),
valid_dlw_load()