Process DLW Data
pipdata_dlw_process.RdThis wrapper function automates key steps in processing DLW data by performing the following tasks:
Checks if the list of GMD DLW datasets is available, if not, get the list
Checks for new datasets in the GMD catalog, downloads them using
dlw::dlw_get_gmd, and save them to the local directory.Validates the downloaded datasets using
pipdata::pipdata_validate_gmdand updates the validation inventory ("gmd_valid_inv").
Usage
pipdata_dlw_process(
inv_gmd_list = "dlw_gmd_inv",
get_dlw_data = TRUE,
validate_dlw_data = TRUE,
log = TRUE,
save_log = TRUE,
check_missing = TRUE,
release = NULL,
identity = NULL,
verbose = getOption("pipdata.verbose", default = TRUE)
)Arguments
- inv_gmd_list
Character. The name of the inventory file containing the list of GMD datasets.
- get_dlw_data
Logical. Whether to check for and download new DLW data. Default is
TRUE.- validate_dlw_data
Logical. Whether to validate newly downloaded datasets. Default is
TRUE.- log
Logical. Whether to keep logging information. Default is
TRUE.- save_log
Logical. Whether to save logging information to a file. Default is
TRUE.- check_missing
Logical. Whether to check for and retrieve missing data. Default is
TRUE.- release
Character. The data release identifier or date, used to configure the working environment.
- identity
Character. One of
"PROD","INT", or"TEST".- verbose
Logical. Controls verbosity of downstream
pipload::pip_write()calls. Default:getOption("pipdata.verbose", default = TRUE).